@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-# Copyright 2013-2014 Facundo Batista
+# Copyright 2013-2015 Facundo Batista
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,6 +16,8 @@
 #
 # For further info, check  https://launchpad.net/encuentro
 
+from __future__ import unicode_literals
+
 """Central panels in the main window, the content part of all the interface."""
 
 import logging
@@ -61,7 +63,7 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
         super(DownloadsWidget, self).__init__('downloads')
         signal.register(self.save_state)
 
-        _headers = (u"Descargando...", u"Estado")
+        _headers = ("Descargando...", "Estado")
         self.setColumnCount(len(_headers))
         self.setHeaderLabels(_headers)
 
@@ -77,10 +79,16 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
         item = self.currentItem()
         self.episodes_widget.show_episode(item.episode_id)
 
+        # adjust the info of episode, as going through EpisodesWidget may
+        # be a dead end (because of filtering)
+        episode = self.episodes_widget.main_window.programs_data[item.episode_id]
+        self.episodes_widget.episode_info.update(episode)
+        self.episodes_widget.main_window.check_download_play_buttons()
+
     def append(self, episode):
         """Append an episode to the downloads list."""
         # add to the list in the GUI
-        item = QTreeWidgetItem((episode.composed_title, u"Encolado"))
+        item = QTreeWidgetItem((episode.composed_title, "Encolado"))
         item.episode_id = episode.episode_id
         self.queue.append((episode, item))
         self.addTopLevelItem(item)
@@ -100,24 +108,24 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
     def start(self):
         """Download started."""
         episode, item = self.queue[self.current]
-        item.setText(1, u"Comenzando")
+        item.setText(1, "Comenzando")
         episode.state = Status.downloading
 
     def progress(self, progress):
         """Advance the progress indicator."""
         _, item = self.queue[self.current]
-        item.setText(1, u"Descargando: %s" % progress)
+        item.setText(1, "Descargando: %s" % progress)
 
     def end(self, error=None):
         """Mark episode as downloaded."""
         episode, item = self.queue[self.current]
         if error is None:
             # downloaded OK
-            gui_msg = u"Terminado ok"
+            gui_msg = "Terminado ok"
             end_state = Status.downloaded
         else:
             # something bad happened
-            gui_msg = unicode(error)
+            gui_msg = str(error).decode("utf8")
             end_state = Status.none
         item.setText(1, gui_msg)
         item.setDisabled(True)
@@ -128,7 +136,7 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
     def cancel(self):
         """The download is being cancelled."""
         episode, item = self.queue[self.current]
-        item.setText(1, u"Cancelado")
+        item.setText(1, "Cancelado")
         episode.state = Status.none
 
     def unqueue(self, episode):
@@ -145,10 +153,10 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
         del self.queue[pos]
         self.takeTopLevelItem(pos)
 
-        # as we removed an item, the cursor goes to other, fix the rest of
-        # the interface
+        # as we removed an item, the cursor goes to other (if any), fix the rest of the interface
         item = self.currentItem()
-        self.episodes_widget.show_episode(item.episode_id)
+        if item is not None:
+            self.episodes_widget.show_episode(item.episode_id)
 
     def pending(self):
         """Return the pending downloads quantity (including current)."""
@@ -172,14 +180,14 @@ class DownloadsWidget(remembering.RememberingTreeWidget):
         """Queue the pending downloads."""
         loaded_pending_ids = config[config.SYSTEM].get('pending_ids', [])
 
+        main_window = self.episodes_widget.main_window
         for episode_id in loaded_pending_ids:
-            main_window = self.episodes_widget.main_window
             try:
                 episode = main_window.programs_data[episode_id]
             except KeyError:
-                logger.debug("Tried to load pending %r, didn't find it",
-                             episode_id)
+                logger.debug("Tried to load pending %r, didn't find it", episode_id)
             else:
+                logger.info("Queuing pending episode %s", episode)
                 main_window.queue_download(episode)
 
 
@@ -248,7 +256,7 @@ class EpisodesWidgetModel(QAbstractTableModel):
         operator.attrgetter('filtered_title'),
         operator.attrgetter('duration'),
     ]
-    _headers = (u"Canal", u"Sección", u"Título", u"Duración [min]")
+    _headers = ("Canal", "Sección", "Título", "Duración [min]")
 
     def __init__(self, main_window):
         super(EpisodesWidgetModel, self).__init__()
@@ -280,7 +288,7 @@ class EpisodesWidgetModel(QAbstractTableModel):
             else:
                 # filtering by text, so highlight
                 t = ep.composed_title
-                ep.filtered_title = u'%s<span style="background-color:yellow">%s</span>%s' % (
+                ep.filtered_title = '%s<span style="background-color:yellow">%s</span>%s' % (
                     t[:pos1], t[pos1:pos2], t[pos2:])
             episodes.append(ep)
 
@@ -331,11 +339,12 @@ class EpisodesWidgetModel(QAbstractTableModel):
             return self._headers[section]
 
     def refresh(self, episode_id):
-        """Refresh the view of an episode."""
-        row = self.pos_map[episode_id]
-        index_from = self.index(row, 0)
-        index_to = self.index(row, len(self._headers) - 1)
-        self.dataChanged.emit(index_from, index_to)
+        """Refresh the view of an episode (if possible, it may be filtered out)."""
+        row = self.pos_map.get(episode_id)
+        if row is not None:
+            index_from = self.index(row, 0)
+            index_to = self.index(row, len(self._headers) - 1)
+            self.dataChanged.emit(index_from, index_to)
 
     def sort(self, n_col, order):
         """Sort data by given column."""
@@ -385,11 +394,12 @@ class EpisodesWidgetView(remembering.RememberingTableView):
         sm.selectionChanged.connect(self.on_change)
 
     def show_episode(self, episode_id):
-        """Show the row for the requested episode."""
-        row = self._model.pos_map[episode_id]
-        index = self._model.index(row, 0)
-        self.scrollTo(index)
-        self._adjust_gui(episode_id)
+        """Show the row for the requested episode, if possible (it may be filtered out)."""
+        row = self._model.pos_map.get(episode_id)
+        if row is not None:
+            index = self._model.index(row, 0)
+            self.scrollTo(index)
+            self._adjust_gui(episode_id)
 
     def selected_items(self):
         """Return the episode ids of the selected items."""
@@ -409,11 +419,11 @@ class EpisodesWidgetView(remembering.RememberingTableView):
             self._adjust_gui(episode_id)
         elif len(indexes) == 0:
             # nothing selected
-            self.episode_info.clear(u"Seleccioná un programa para ver aquí la info.")
+            self.episode_info.clear("Seleccioná un programa para ver aquí la info.")
             self.main_window.check_download_play_buttons()
         else:
             # multiple selection
-            self.episode_info.clear(u"Seleccioná sólo un programa para ver aquí la info.")
+            self.episode_info.clear("Seleccioná sólo un programa para ver aquí la info.")
             self.main_window.check_download_play_buttons()
 
     def on_activate(self, index):
@@ -429,8 +439,8 @@ class EpisodesWidgetView(remembering.RememberingTableView):
                 self.main_window.queue_download(episode)
             else:
                 logger.debug("Not starting download because no config.")
-                t = u"No se puede arrancar una descarga porque la configuración está incompleta."
-                self.main_window.show_message(u'Falta configuración', t)
+                t = "No se puede arrancar una descarga porque la configuración está incompleta."
+                self.main_window.show_message('Falta configuración', t)
 
     def _adjust_gui(self, episode_id):
         """Adjust the rest of the GUI for this episode."""
@@ -454,9 +464,9 @@ class EpisodesWidgetView(remembering.RememberingTableView):
         episode = self.main_window.programs_data[episode_id]
         menu = QMenu()
         mw = self.main_window
-        act_play = menu.addAction(u"&Reproducir", lambda: mw.play_episode(episode))
-        act_cancel = menu.addAction(u"&Cancelar descarga", lambda: mw.cancel_download(episode))
-        act_download = menu.addAction(u"&Descargar", lambda: mw.queue_download(episode))
+        act_play = menu.addAction("&Reproducir", lambda: mw.play_episode(episode))
+        act_cancel = menu.addAction("&Cancelar descarga", lambda: mw.cancel_download(episode))
+        act_download = menu.addAction("&Descargar", lambda: mw.queue_download(episode))
 
         # set menu options according status
         state = episode.state
@@ -511,8 +521,7 @@ class EpisodeInfo(QWidget):
         self.get_image = image.ImageGetter(self.image_episode_loaded).get_image
 
         # text area
-        self.text_edit = QTextEdit(
-            u"Seleccionar un programa para ver aquí la info.")
+        self.text_edit = QTextEdit("Seleccionar un programa para ver aquí la info.")
         self.text_edit.setReadOnly(True)
         layout.addWidget(self.text_edit)
 
@@ -570,12 +579,13 @@ class EpisodeInfo(QWidget):
             self.get_image(episode.episode_id, episode.image_url.encode('utf-8'))
 
         # all description
+        description = episode.description.replace("\n", "<br/>")
         if episode.subtitle is None:
-            msg = u"<center><h3>%s</h3></center><br/><br/>%s" % (
-                episode.composed_title, episode.description)
+            msg = "<center><h3>%s</h3></center><br/><br/>%s" % (
+                episode.composed_title, description)
         else:
-            msg = u"<center><h3>%s</h3>%s</center><br/><br/>%s" % (
-                episode.composed_title, episode.subtitle, episode.description)
+            msg = "<center><h3>%s</h3>%s</center><br/><br/>%s" % (
+                episode.composed_title, episode.subtitle, description)
         self.text_edit.setHtml(msg)
 
         # action button
@@ -586,17 +596,17 @@ class EpisodeInfo(QWidget):
             enable = True
             remove = False
         elif episode.state == data.Status.downloading:
-            label = u"Cancelar descarga"
+            label = "Cancelar descarga"
             func = self.main_window.cancel_download
             enable = True
             remove = False
         elif episode.state == data.Status.waiting:
-            label = u"Sacar de la cola"
+            label = "Sacar de la cola"
             func = self.main_window.unqueue_download
             enable = True
             remove = True
         else:
-            label = u"Descargar"
+            label = "Descargar"
             func = self.main_window.download_episode
             enable = bool(self.main_window.have_config())
             remove = False
