@@ -1,6 +1,6 @@
 # -*- coding: utf8 -*-
 
-# Copyright 2011-2015 Facundo Batista
+# Copyright 2011-2017 Facundo Batista
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -23,21 +23,21 @@ from __future__ import unicode_literals
 import bz2
 import json
 import logging
+import os
+
 from datetime import datetime
-from encuentro.config import config
 
 import defer
 
+from PyQt4.QtGui import QApplication
+
 from encuentro import utils
+from encuentro.config import config
 from encuentro.ui import dialogs
 
 # main entry point to download all backends data
-BACKENDS_URL = "http://www.taniquetil.com.ar/encuentro/backends-v06.list"
-
-# if developing a new backend, put the tuple here; otherwise leave it in None.
-# the tuple is name, downloader, and path
-BACKEND_TEST_DATA = None
-#    ("cda", "chunks", "/home/facundo/devel/reps/encuentro/cda/server/cda-v05.bz2")
+BACKENDS_BASE_URL = "http://www.taniquetil.com.ar/encuentro/"
+BACKENDS_LIST = "backends-v07.list"
 
 logger = logging.getLogger('encuentro.update')
 
@@ -45,8 +45,9 @@ logger = logging.getLogger('encuentro.update')
 class UpdateEpisodes(object):
     """Update the episodes info."""
 
-    def __init__(self, main_window):
+    def __init__(self, main_window, update_source):
         self.main_window = main_window
+        self.update_source = update_source
 
     def background(self):
         """Trigger an update in background."""
@@ -59,13 +60,30 @@ class UpdateEpisodes(object):
         self._update(dialog)
 
     @defer.inline_callbacks
-    def _update(self, dialog=None):
-        """Update the content from server.
+    def _get(self, filename):
+        """Get the content from the server or a local source."""
+        if self.update_source is None:
+            # from the server
+            url = BACKENDS_BASE_URL + filename
+            logger.debug("Getting content from url %r", url)
+            _, content = yield utils.download(url)
+        else:
+            # from a local source
+            filepath = os.path.join(self.update_source, filename)
+            logger.debug("Getting content from filepath %r", filepath)
+            with open(filepath, 'rb') as fh:
+                content = fh.read()
 
-        If we have a dialog (interactive update), check frequently if
-        it was closed, so we stop working for that request.
-        """
+        defer.return_value(content)
+
+    @defer.inline_callbacks
+    def _update(self, dialog=None):
+        """Update the content from source, being it server or something indicated at start."""
         if dialog:
+            # when loading from disk we won't free the CPU much, so let's
+            # leave some time for Qt to work (here on start and on each message below)
+            QApplication.processEvents()
+
             def tell_user(template, *elements):
                 if elements:
                     try:
@@ -76,13 +94,15 @@ class UpdateEpisodes(object):
                 else:
                     msg = template
                 dialog.append(msg)
+                QApplication.processEvents()
         else:
-            tell_user = lambda *t: None
+            def tell_user(*t):
+                """Do nothing."""
 
         logger.info("Downloading backend list")
         tell_user("Descargando la lista de backends...")
         try:
-            _, backends_file = yield utils.download(BACKENDS_URL)
+            backends_file = yield self._get(BACKENDS_LIST)
         except Exception as e:
             logger.error("Problem when downloading backends: %s", e)
             tell_user("Hubo un PROBLEMA al bajar la lista de backends: %s", e)
@@ -93,11 +113,11 @@ class UpdateEpisodes(object):
                          if l and l[0] != '#']
 
         backends = {}
-        for b_name, b_dloader, b_url in backends_list:
+        for b_name, b_dloader, b_filename in backends_list:
             logger.info("Downloading backend metadata for %r", b_name)
             tell_user("Descargando la lista de episodios para backend %r...", b_name)
             try:
-                _, compressed = yield utils.download(b_url)
+                compressed = yield self._get(b_filename)
             except Exception as e:
                 logger.error("Problem when downloading episodes: %s", e)
                 tell_user("Hubo un PROBLEMA al bajar los episodios: %s", e)
@@ -114,27 +134,6 @@ class UpdateEpisodes(object):
                 item['downtype'] = b_dloader
             backends[b_name] = content
 
-        if BACKEND_TEST_DATA is not None:
-            b_name, b_dloader, b_path = BACKEND_TEST_DATA
-            logger.info("Grabbing test backend metadata for %r", b_name)
-            tell_user("Usando la lista de episodios para backend de prueba %r...", b_name)
-            try:
-                with open(b_path, "rb") as fh:
-                    compressed = fh.read()
-            except Exception as e:
-                logger.error("Problem when reading test file: %s", e)
-                tell_user("Hubo un PROBLEMA al leer el archivo de prueba: %s", e)
-                return
-
-            tell_user("Descomprimiendo el archivo....")
-            new_content = bz2.decompress(compressed)
-            logger.debug("Grabbed data decompressed ok")
-
-            content = json.loads(new_content)
-            for item in content:
-                item['downtype'] = b_dloader
-            backends[b_name] = content
-
         if dialog and dialog.closed:
             return
         tell_user("Conciliando datos de diferentes backends")
